@@ -1,7 +1,9 @@
 def __bootstrap__():
     global __bootstrap__, __loader__, __file__
-    import sys, pkg_resources, imp
+    import sys, pkg_resources, importlib.util
     __file__ = pkg_resources.resource_filename(__name__, '_internals.cp37-win_amd64.pyd')
     __loader__ = None; del __bootstrap__, __loader__
-    imp.load_dynamic(__name__,__file__)
+    spec = importlib.util.spec_from_file_location(__name__,__file__)
+    mod = importlib.util.module_from_spec(spec)
+    spec.loader.exec_module(mod)
 __bootstrap__()
